# Community

This section is WIP.

```{toctree}
toolboxes.md
contributing_code.md
contributors.md
```

## Discussion Forum
To discuss with the community or get help please visit the [Cedalion Forum on openfnirs.org](https://openfnirs.org/community/cedalion/)
